@@ -11,60 +11,6 @@ from itertools import chain
 import pkg_resources
 
 
-# RTD hack start
-def patch_setuptools_in_rtd():
-    """Install newer setuptools and octomachinery in RTD."""
-    import os  # pylint: disable=import-outside-toplevel
-    import sys  # pylint: disable=import-outside-toplevel
-    import subprocess  # pylint: disable=import-outside-toplevel
-
-    if not os.getenv('READTHEDOCS') or os.getenv('READTHEDOCS_EXEC'):
-        return
-
-    # pylint: disable=unexpected-keyword-arg
-    pyenv_python_executable = subprocess.check_output(
-        ('pyenv', 'which', 'python3.7'), text=True,
-    ).strip()
-    setuptools_update_cmd = (
-        pyenv_python_executable, '-m',
-        'pip', 'install', '--force-reinstall',
-        '--cache-dir', '/home/docs/checkouts/readthedocs.org/user_builds'
-        '/octomachinery/.cache/pip', 'setuptools >= 40.9.0',
-    )
-    pip_update_cmd = (
-        sys.executable, '-m',
-        'pip', 'install', '--force-reinstall',
-        '--cache-dir', '/home/docs/checkouts/readthedocs.org/user_builds'
-        '/octomachinery/.cache/pip', 'pip >= 19.0.3',
-    )
-    octomachinery_install_cmd = (
-        sys.executable, '-m',
-        'pip', 'install', '--force-reinstall',
-        '--cache-dir', '/home/docs/checkouts/readthedocs.org/user_builds'
-        '/octomachinery/.cache/pip', '..[docs]',
-    )
-    print('>>>>> Bumping setuptools...', file=sys.stderr)
-    subprocess.check_call(setuptools_update_cmd)
-    print('>>>>> Bumping pip...', file=sys.stderr)
-    subprocess.check_call(pip_update_cmd)
-    print('>>>>> Installing octomachinery...', file=sys.stderr)
-    subprocess.check_call(octomachinery_install_cmd)
-
-    new_env = dict(os.environ)
-    new_env['READTHEDOCS_EXEC'] = 'True'
-
-    print('>>>>> Restarting Sphinx build...', file=sys.stderr)
-    print(
-        f'Sphinx build command is `{sys.executable} {" ".join(sys.argv)}`',
-        file=sys.stderr,
-    )
-    os.execve(sys.executable, (sys.executable, *sys.argv), new_env)
-
-
-patch_setuptools_in_rtd()
-del patch_setuptools_in_rtd
-# RTD hack end
-
 # -- Path setup --------------------------------------------------------------
 
 # If extensions (or modules to document with autodoc) are in another directory,
@@ -192,7 +138,9 @@ language = None
 exclude_patterns = []
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+# NOTE: These values are commented out so that Furo fall back to a nice style
+# pygments_style = 'sphinx'
+# pygments_dark_style = 'monokai'
 
 
 # -- Options for HTML output -------------------------------------------------
@@ -200,27 +148,13 @@ pygments_style = 'sphinx'
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = 'alabaster'
+html_theme = 'furo'
 
 # Theme options are theme-specific and customize the look and feel of a theme
 # further.  For a list of options available for each theme, see the
 # documentation.
 #
-html_theme_options = {
-    'description': PRJ_SUMMARY,
-    'github_user': PRJ_GITHUB_USER,
-    'github_repo': PRJ_GITHUB_REPO,
-    'github_type': 'star',
-    'github_banner': True,
-    'travis_button': True,
-    # 'travis_tld': 'com',
-    'show_relbars': True,
-    'show_related': True,
-    'extra_nav_links': {
-        'Create a GitHub bot 🤖': 'https://tutorial.octomachinery.dev',
-        'octomachinery [www] 🤖': 'https://octomachinery.dev',
-    },
-}
+# html_theme_options = {}
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -235,7 +169,18 @@ html_static_path = ['_static']
 # default: ``['localtoc.html', 'relations.html', 'sourcelink.html',
 # 'searchbox.html']``.
 #
-# html_sidebars = {}
+html_sidebars = {
+    '**': (
+        'sidebar/brand.html',
+        'project-description.html',
+        'sidebar/search.html',
+        'sidebar/scroll-start.html',
+        'sidebar/navigation.html',
+        'github-sponsors.html',
+        'sidebar/ethical-ads.html',
+        'sidebar/scroll-end.html',
+    ),
+}
 
 
 # -- Options for HTMLHelp output ---------------------------------------------
@@ -270,7 +215,7 @@ latex_elements = {
 latex_documents = [
     (
         master_doc, f'{project}.tex', f'{project} Documentation',
-        'Sviatoslav Sydorenko (@webknjaz)', 'manual',
+        author, 'manual',
     ),
 ]
 
@@ -339,36 +284,18 @@ intersphinx_mapping = {
 todo_include_todos = True
 
 
-# Patch alabaster theme
-# Ref: https://github.com/bitprophet/alabaster/pull/147
-# FIXME: drop this hack once the PR is merged & released; pylint: disable=fixme
-def set_up_travis_context(
+def set_up_template_context(
         app, pagename, templatename,  # pylint: disable=unused-argument
         context,
         doctree,  # pylint: disable=unused-argument
 ):
-    """Add complete Travis URLs to Jinja2 context."""
-    github_slug = '/'.join(
-        # (context['theme_github_user'], context['theme_github_repo']),
-        (PRJ_GITHUB_USER, PRJ_GITHUB_REPO),
-    )
-
-    travis_button = 'true'  # str(context['theme_travis_button']).lower()
-    travis_button_enabled = travis_button == 'true'
-
-    travis_slug = github_slug if travis_button_enabled else travis_button
-
-    travis_tld = 'com'  # context["theme_travis_tld"].strip(".").lower()
-    travis_base_uri = 'travis-ci.{}/{}'.format(travis_tld, travis_slug)
-    context['theme_travis_build_url'] = 'https://{}'.format(travis_base_uri)
-    context['theme_travis_badge_url'] = 'https://api.{}.svg?branch={}'.format(
-        travis_base_uri, 'master',  # context['theme_badge_branch'],
-    )
+    """Add a dist summary to Jinja2 context."""
+    context['theme_prj_summary'] = PRJ_SUMMARY
 
 
 def setup(app):
     """Patch the sphinx theme set up stage."""
-    app.connect('html-page-context', set_up_travis_context)
+    app.connect('html-page-context', set_up_template_context)
 
 
 # Ref: https://github.com/python-attrs/attrs/pull/571/files\
